#include "spawn.h"

#include "..\algorithms.h"

void botInfo::gotHelp(Player *p, Command *c)
{
	// List commands

	if (!*c->final)
	{
		switch (p->access)
		{
		case OP_Duke:
		case OP_Baron:
		case OP_King:
		case OP_Emperor:
		case OP_RockStar:
		case OP_Q:
		case OP_God:
		case OP_Owner:
			{	// Owner-level commands
			}
		case OP_SysOp:
			{	// SysOp-level commands
			}
		case OP_SuperModerator:
			{	// SuperModerator-level commands
			}
		case OP_Moderator:
			{	// Moderator-level commands
			}
		case OP_Limited:
			{	// Limited-level commands
				if (state == ELIM_Playing)
					sendPrivate(p, "Ext: !about !status !rank !force !stop !autospec !maketeams");
				else
					sendPrivate(p, "Ext: !about !status !rank !start !autospec !maketeams");
			}
			break;
		case OP_Player:
			{	// Player-level commands
				sendPrivate(p, "Ext: !about !status !rank");
			}
		}

		return;
	}

	// Specific command help

	switch (p->access)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
			if (c->checkParam("owner") || c->checkParam("all"))
			{
			}
		}
	case OP_SysOp:
		{	// SysOp-level commands
			if (c->checkParam("sop") || c->checkParam("all"))
			{
			}
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
			if (c->checkParam("smod") || c->checkParam("all"))
			{
			}
		}
	case OP_Moderator:
		{	// Moderator-level commands
			if (c->checkParam("mod") || c->checkParam("all"))
			{
				if (state == ELIM_Playing)
					sendPrivate(p, "Ext: !about !status !rank !force !stop !autospec !maketeams !zonedelay");
				else
					sendPrivate(p, "Ext: !about !status !rank !force !start !autospec !maketeams !zonedelay");
			}
		}
	case OP_Limited:
		{	// Limited-level commands
			if (c->checkParam("force"))
			{
				sendPrivate(p, "!force <choice> (force a decision)");
			}
			else if (c->checkParam("start"))
			{
				sendPrivate(p, "!start (begin a game of elimination)");
			}
			else if (c->checkParam("stop"))
			{
				sendPrivate(p, "!stop (end a game in progress)");
			}
			else if (c->checkParam("autospec"))
			{
				sendPrivate(p, "!autospec [number of deaths] (auto-spectate players after a number of deaths)");
				sendPrivate(p, "!autospec OFF (turn off this feature)");
			}
			else if (c->checkParam("maketeams"))
			{
				sendPrivate(p, "!maketeams <number per team> (organize arena into teams of X players)");
			}
			else if (c->checkParam("zonedelay"))
			{
				sendPrivate(p, "!zonedelay [minutes] (set or view minimum delay between *zone announcements for elim)");
			}
		}
	case OP_Player:
		{	// Player-level commands
			if (c->checkParam("about"))
			{
				sendPrivate(p, "!about (query me about my function)");
			}
			else if (c->checkParam("status"))
			{
				sendPrivate(p, "!status (what's up doc?)");
			}
			else if (c->checkParam("rank"))
			{
				sendPrivate(p, "!rank [player name] (display player rank)");
			}
		}
	}
}

void botInfo::gotCommand(Player *p, Command *c)
{
	if (!p) return;
	if (!c) return;

	switch (p->access)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
			if (c->check("version"))
			{
				sendPrivate(p, "[name:elim.dll] [maker:Catid@pacbell.net] [build:4]");
			}
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
			if (state != ELIM_NotPlaying)
			{
				if (c->check("stop"))
				{
					sendPublic(SND_BassBeep, "*arena Elimination cancelled[forced].");

					if (state == ELIM_Playing)
					{
						if ((game != GAME_Zombies) && (game != GAME_Race))
							sendPublic("*lock");
					}

					state = ELIM_NotPlaying;
				}
				else if (state == ELIM_VotingGame || state == ELIM_VotingDeaths)
				{
					if (c->check("force"))
					{
						if (isNumeric(c->final))
						{
							int value = getInteger(c->final, 10);
							if ((value >= 1) || value <= 9)
							{
								votes[value] += 500;

								countdown[0] = 1;
							}
						}
					}
				}
			}
			else
			{
				if (c->check("start"))
				{
					if (!sendGreet())
						sendPrivate(p, "Game restarting. I have already sent a *zone message in the last 2 minutes");

					state = ELIM_Announcing;
					countdown[0] = 1;
				}
			}

			if (c->check("zonedelay"))
			{
				if (isNumeric(c->final))
				{
					int value = getInteger(c->final, 10);

					if (value < 1) value = 1;
					else if (value > 60) value = 60;

					zonedelay = value * 60;

					String s;
					s += value;
					s += " minutes minimum between *zone announcements for elim";
					sendPrivate(p, s);
				}
				else
				{
					String s;
					s += zonedelay / 60;
					s += " minutes minimum between *zone announcements for elim";
					sendPrivate(p, s);
				}
			}
			else if (c->check("autospec"))
			{
				if (isNumeric(c->final))
				{
					autospec_deaths = getInteger(c->final, 10);
					autospec_enabled = true;

					if (autospec_deaths < 0) autospec_deaths = 1;
					if (autospec_deaths > 999) autospec_deaths = 999;

					String s;
					s += "*arenaRemoving players with ";
					s += autospec_deaths;
					s += " deaths";
					sendPublic(SND_TrebleBeep, s);

					// Find current offenders
					_listnode <Player> *parse = playerlist->head;

					while (parse)
					{
						Player *pp = parse->item;

						if (pp->score.losses >= autospec_deaths)
						{
							sendPrivate(pp, "*spec");
							sendPrivate(pp, "*spec");
						}

						parse = parse->next;
					}
				}
				else if (c->checkParam("off"))
				{
					if (autospec_enabled)
					{
						sendPublic(SND_TrebleBeep, "*arenaNOT removing players based on deaths");
					}

					autospec_enabled = false;

					sendPrivate(p, "Auto-spectate disabled.");
				}
			}
			else if (c->check("maketeams"))
			{
				if (isNumeric(c->final))
				{
					int teams = getInteger(c->final, 10);

					if (teams < 0) teams = 1;
					if (teams > 999) teams = 999;

					String s;
					s += "*arenaOrganizing arena into teams of ";
					s += teams;
					s += " players.";
					sendPublic(SND_TrebleBeep, s);

					_listnode <Player> *parse = playerlist->head;
					int count = 0, freq = 0;

					while (parse)
					{
						Player *pp = parse->item;
						parse = parse->next;

						if (pp->ship == SHIP_Spectator)
							continue;

						if (pp->team != freq)
						{
							String s;
							s += "*setfreq ";
							s += freq;
							sendPrivate(pp, s);
						}

						++count;
						if (count == teams)
						{
							count = 0;
							++freq;
						}
					}
				}
				else
				{
					sendPrivate(p, "Invalid syntax. Type ::!help maketeams");
				}
			}
		}
	case OP_Player:
		{	// Player-level commands
			if (c->check("about"))
			{
				sendPrivate(p, "I host various classic SubSpace games.");
			}
			else if (c->check("status"))
			{
				sendPrivate(p, getStatus());
			}
			else if (c->check("rank"))
			{
				sendPrivate(p, "Yeah, you're pretty rank alright.");
			}
		}
	}
}

void botInfo::gotRemoteHelp(char *p, Command *c, Operator_Level l)
{
	// List commands

	if (!*c->final)
	{
		switch (l)
		{
		case OP_Duke:
		case OP_Baron:
		case OP_King:
		case OP_Emperor:
		case OP_RockStar:
		case OP_Q:
		case OP_God:
		case OP_Owner:
			{	// Owner-level commands
			}
		case OP_SysOp:
			{	// SysOp-level commands
			}
		case OP_SuperModerator:
			{	// SuperModerator-level commands
			}
		case OP_Moderator:
			{	// Moderator-level commands
			}
		case OP_Limited:
			{	// Limited-level commands
			}
		case OP_Player:
			{	// Player-level commands
			}
		}

		return;
	}

	// Specific command help

	switch (l)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
		}
	}
}

void botInfo::gotRemote(char *p, Command *c, Operator_Level l)
{
	if (!c) return;

	switch (l)
	{
	case OP_Duke:
	case OP_Baron:
	case OP_King:
	case OP_Emperor:
	case OP_RockStar:
	case OP_Q:
	case OP_God:
	case OP_Owner:
		{	// Owner-level commands
		}
	case OP_SysOp:
		{	// SysOp-level commands
		}
	case OP_SuperModerator:
		{	// SuperModerator-level commands
		}
	case OP_Moderator:
		{	// Moderator-level commands
		}
	case OP_Limited:
		{	// Limited-level commands
		}
	case OP_Player:
		{	// Player-level commands
		}
	}
}
